<?php

include __DIR__."/builtin_extensions.inc";

class A_DOMAttr extends DOMAttr {
  public $___x;
}
test("DOMAttr", "Hello");
